@@ -15,50 +15,46 @@ func BIF_length(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	switch input1.Type() {
 	case mlrval.MT_ERROR:
 		return mlrval.FromInt(0)
-		break
 	case mlrval.MT_ABSENT:
 		return mlrval.FromInt(0)
-		break
 	case mlrval.MT_ARRAY:
 		arrayval := input1.AcquireArrayValue()
-		return mlrval.FromInt(int(len(arrayval)))
-		break
+		return mlrval.FromInt(int64(len(arrayval)))
 	case mlrval.MT_MAP:
 		mapval := input1.AcquireMapValue()
-		return mlrval.FromInt(int(mapval.FieldCount))
-		break
+		return mlrval.FromInt(mapval.FieldCount)
 	}
 	return mlrval.FromInt(1)
 }
 
 // ================================================================
 func depth_from_array(input1 *mlrval.Mlrval) *mlrval.Mlrval {
-	maxChildDepth := 0
+	maxChildDepth := int64(0)
 	arrayval := input1.AcquireArrayValue()
 	for _, child := range arrayval {
-		childDepth := BIF_depth(&child)
+		childDepth := BIF_depth(child)
 		lib.InternalCodingErrorIf(!childDepth.IsInt())
-		iChildDepth := int(childDepth.AcquireIntValue())
+		iChildDepth := childDepth.AcquireIntValue()
 		if iChildDepth > maxChildDepth {
 			maxChildDepth = iChildDepth
 		}
 	}
-	return mlrval.FromInt(int(1 + maxChildDepth))
+	return mlrval.FromInt(1 + maxChildDepth)
 }
 
 func depth_from_map(input1 *mlrval.Mlrval) *mlrval.Mlrval {
-	maxChildDepth := 0
+	maxChildDepth := int64(0)
 	mapval := input1.AcquireMapValue()
 	for pe := mapval.Head; pe != nil; pe = pe.Next {
 		child := pe.Value
 		childDepth := BIF_depth(child)
 		lib.InternalCodingErrorIf(!childDepth.IsInt())
-		iChildDepth := int(childDepth.AcquireIntValue())
+		iChildDepth := childDepth.AcquireIntValue()
 		if iChildDepth > maxChildDepth {
 			maxChildDepth = iChildDepth
 		}
 	}
-	return mlrval.FromInt(int(1 + maxChildDepth))
+	return mlrval.FromInt(1 + maxChildDepth)
 }
 
 func depth_from_scalar(input1 *mlrval.Mlrval) *mlrval.Mlrval {
@@ -91,7 +87,7 @@ func BIF_depth(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 
 // ================================================================
 func leafcount_from_array(input1 *mlrval.Mlrval) *mlrval.Mlrval {
-	sumChildLeafCount := 0
+	sumChildLeafCount := int64(0)
 	arrayval := input1.AcquireArrayValue()
 	for _, child := range arrayval {
 		// Golang initialization loop if we do this :(
@@ -99,20 +95,20 @@ func leafcount_from_array(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 
 		childLeafCount := mlrval.FromInt(1)
 		if child.IsArray() {
-			childLeafCount = leafcount_from_array(&child)
+			childLeafCount = leafcount_from_array(child)
 		} else if child.IsMap() {
-			childLeafCount = leafcount_from_map(&child)
+			childLeafCount = leafcount_from_map(child)
 		}
 
 		lib.InternalCodingErrorIf(!childLeafCount.IsInt())
-		iChildLeafCount := int(childLeafCount.AcquireIntValue())
+		iChildLeafCount := childLeafCount.AcquireIntValue()
 		sumChildLeafCount += iChildLeafCount
 	}
-	return mlrval.FromInt(int(sumChildLeafCount))
+	return mlrval.FromInt(sumChildLeafCount)
 }
 
 func leafcount_from_map(input1 *mlrval.Mlrval) *mlrval.Mlrval {
-	sumChildLeafCount := 0
+	sumChildLeafCount := int64(0)
 	mapval := input1.AcquireMapValue()
 	for pe := mapval.Head; pe != nil; pe = pe.Next {
 		child := pe.Value
@@ -128,10 +124,10 @@ func leafcount_from_map(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 		}
 
 		lib.InternalCodingErrorIf(!childLeafCount.IsInt())
-		iChildLeafCount := int(childLeafCount.AcquireIntValue())
+		iChildLeafCount := childLeafCount.AcquireIntValue()
 		sumChildLeafCount += iChildLeafCount
 	}
-	return mlrval.FromInt(int(sumChildLeafCount))
+	return mlrval.FromInt(sumChildLeafCount)
 }
 
 func leafcount_from_scalar(input1 *mlrval.Mlrval) *mlrval.Mlrval {
@@ -165,7 +161,7 @@ func has_key_in_array(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 		return mlrval.ERROR
 	}
 	arrayval := input1.AcquireArrayValue()
-	_, ok := unaliasArrayIndex(&arrayval, input2.AcquireIntValue())
+	_, ok := unaliasArrayIndex(&arrayval, int(input2.AcquireIntValue()))
 	return mlrval.FromBool(ok)
 }
 
@@ -187,6 +183,24 @@ func BIF_haskey(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	}
 }
 
+// ================================================================
+func BIF_concat(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
+	output := mlrval.FromEmptyArray()
+
+	for _, arg := range mlrvals {
+		argArray := arg.GetArray()
+		if argArray == nil { // not an array
+			output.ArrayAppend(arg.Copy())
+		} else {
+			for i := range argArray {
+				output.ArrayAppend(argArray[i].Copy())
+			}
+		}
+	}
+
+	return output
+}
+
 // ================================================================
 func BIF_mapselect(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	if len(mlrvals) < 1 {
@@ -556,11 +570,11 @@ func BIF_splita(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 
 	fields := lib.SplitString(input1.AcquireStringValue(), fieldSeparator)
 
-	arrayval := make([]mlrval.Mlrval, len(fields))
+	arrayval := make([]*mlrval.Mlrval, len(fields))
 
 	for i, field := range fields {
 		value := mlrval.FromInferredType(field)
-		arrayval[i] = *value
+		arrayval[i] = value
 	}
 
 	return mlrval.FromArray(arrayval)
@@ -587,10 +601,10 @@ func BIF_splitax(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 func bif_splitax_helper(input string, separator string) *mlrval.Mlrval {
 	fields := lib.SplitString(input, separator)
 
-	arrayval := make([]mlrval.Mlrval, len(fields))
+	arrayval := make([]*mlrval.Mlrval, len(fields))
 
 	for i, field := range fields {
-		arrayval[i] = *mlrval.FromString(field)
+		arrayval[i] = mlrval.FromString(field)
 	}
 
 	return mlrval.FromArray(arrayval)
@@ -601,19 +615,19 @@ func BIF_get_keys(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsMap() {
 		// TODO: make a ReferenceFrom with comments
 		mapval := input1.AcquireMapValue()
-		arrayval := make([]mlrval.Mlrval, mapval.FieldCount)
+		arrayval := make([]*mlrval.Mlrval, mapval.FieldCount)
 		i := 0
 		for pe := mapval.Head; pe != nil; pe = pe.Next {
-			arrayval[i] = *mlrval.FromString(pe.Key)
+			arrayval[i] = mlrval.FromString(pe.Key)
 			i++
 		}
 		return mlrval.FromArray(arrayval)
 
 	} else if input1.IsArray() {
 		inputarrayval := input1.AcquireArrayValue()
-		arrayval := make([]mlrval.Mlrval, len(inputarrayval))
+		arrayval := make([]*mlrval.Mlrval, len(inputarrayval))
 		for i := range inputarrayval {
-			arrayval[i] = *mlrval.FromInt(int(i + 1)) // Miller user-space indices are 1-up
+			arrayval[i] = mlrval.FromInt(int64(i + 1)) // Miller user-space indices are 1-up
 		}
 		return mlrval.FromArray(arrayval)
 
@@ -626,19 +640,19 @@ func BIF_get_keys(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 func BIF_get_values(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsMap() {
 		mapval := input1.AcquireMapValue()
-		arrayval := make([]mlrval.Mlrval, mapval.FieldCount)
+		arrayval := make([]*mlrval.Mlrval, mapval.FieldCount)
 		i := 0
 		for pe := mapval.Head; pe != nil; pe = pe.Next {
-			arrayval[i] = *pe.Value.Copy()
+			arrayval[i] = pe.Value.Copy()
 			i++
 		}
 		return mlrval.FromArray(arrayval)
 
 	} else if input1.IsArray() {
 		inputarrayval := input1.AcquireArrayValue()
-		arrayval := make([]mlrval.Mlrval, len(inputarrayval))
+		arrayval := make([]*mlrval.Mlrval, len(inputarrayval))
 		for i, value := range inputarrayval {
-			arrayval[i] = *value.Copy()
+			arrayval[i] = value.Copy()
 		}
 		return mlrval.FromArray(arrayval)
 
@@ -725,10 +739,10 @@ func BIF_arrayify(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 
 		if convertible {
 			mapval := input1.AcquireMapValue()
-			arrayval := make([]mlrval.Mlrval, input1.AcquireMapValue().FieldCount)
+			arrayval := make([]*mlrval.Mlrval, input1.AcquireMapValue().FieldCount)
 			i := 0
 			for pe := mapval.Head; pe != nil; pe = pe.Next {
-				arrayval[i] = *pe.Value.Copy()
+				arrayval[i] = pe.Value.Copy()
 				i++
 			}
 			return mlrval.FromArray(arrayval)
@@ -740,8 +754,9 @@ func BIF_arrayify(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	} else if input1.IsArray() {
 		// TODO: comment (or rethink) that this modifies its inputs!!
 		output := input1.Copy()
+		arrayval := output.AcquireArrayValue()
 		for i := range input1.AcquireArrayValue() {
-			output.AcquireArrayValue()[i] = *BIF_arrayify(&output.AcquireArrayValue()[i])
+			arrayval[i] = BIF_arrayify(arrayval[i])
 		}
 		return output
 
@@ -793,7 +808,7 @@ func BIF_json_stringify_binary(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	}
 }
 
-func unaliasArrayIndex(array *[]mlrval.Mlrval, mindex int) (int, bool) {
+func unaliasArrayIndex(array *[]*mlrval.Mlrval, mindex int) (int, bool) {
 	n := int(len(*array))
 	return unaliasArrayLengthIndex(n, mindex)
 }
@@ -850,3 +865,101 @@ func unaliasArrayLengthIndex(n int, mindex int) (int, bool) {
 		return -1, false
 	}
 }
+
+// MillerSliceAccess is code shared by the string-slicer and the array-slicer.
+// * Miller indices are 1-up, 1..n where n is the length of the array/string.
+//   They are also aliased -n..-1. These are called "mindex" (if int) or "index mlrval"
+//   (if mlrval).
+// * Go indices are 0-up, with no aliasing. These are called "zindex".
+// * The job of this routine is to map a pair of index-mlrval to a pair of zindex,
+//   with possible outcomes that the slice access should result in an empty array/string,
+//   or Mlrval of type absent, or Mlrval of type error.
+// * Callsites include the DSL array-slicer (e.g. [1,2,3,4,5][2:3]), the DSL string-slicer
+//   (e.g. "abcde"[2:3]), the substr1 function (e.g. substr1("abcde", 2, 3), and the substr0
+//   function (e.g. substr0("abcde", 1, 2)).
+// * The isZeroUp argument is in support of substr0.
+func MillerSliceAccess(
+	lowerIndexMlrval *mlrval.Mlrval,
+	upperIndexMlrval *mlrval.Mlrval,
+	n int, // length of array/string to be sliced
+	isZeroUp bool, // false for array/string slices, and substr1; true for substr0
+) (
+	sliceIsEmpty bool, // true if the output of the slice should empty string/array
+	absentOrError *mlrval.Mlrval, // non-nil if the output of the slice should be absent/error
+	lowerZindex int, // lower zindex if first two return values are false & nil
+	upperZindex int, // upper zindex if first two return values are false & nil
+) {
+
+	if lowerIndexMlrval.IsAbsent() {
+		return false, mlrval.ABSENT, 0, 0
+	}
+	if upperIndexMlrval.IsAbsent() {
+		return false, mlrval.ABSENT, 0, 0
+	}
+
+	lowerIndex, ok := lowerIndexMlrval.GetIntValue()
+	if !ok {
+		if lowerIndexMlrval.IsVoid() {
+			lowerIndex = 1
+		} else {
+			return false, mlrval.ERROR, 0, 0
+		}
+	}
+	upperIndex, ok := upperIndexMlrval.GetIntValue()
+	if !ok {
+		if upperIndexMlrval.IsVoid() {
+			upperIndex = int64(n)
+		} else {
+			return false, mlrval.ERROR, 0, 0
+		}
+	}
+
+	// For substr0:
+	if isZeroUp && lowerIndex >= 0 {
+		lowerIndex += 1 // make it 1-up
+	}
+	if isZeroUp && upperIndex >= 0 {
+		upperIndex += 1 // make it 1-up
+	}
+
+	// UnaliasArrayIndex returns a boolean second return value to indicate
+	// whether the index is in range. But here, for the slicing operation, we
+	// inspect the in-range-ness ourselves so we discard that 2nd return value.
+	// This is because out-of-bounds accesses for single elements have different
+	// semantics than out-of-bounds accesses for slices. See also
+	// https://miller.readthedocs.io/en/latest/reference-main-strings/#slicing
+	// https://miller.readthedocs.io/en/latest/reference-main-arrays/#slicing
+
+	lowerZindex, _ = mlrval.UnaliasArrayLengthIndex(n, int(lowerIndex))
+	upperZindex, _ = mlrval.UnaliasArrayLengthIndex(n, int(upperIndex))
+
+	if lowerZindex > upperZindex {
+		return true, nil, 0, 0
+	}
+
+	// Semantics: say x=[1,2,3,4,5]. Then x[3:10] is [3,4,5].
+	//
+	// Cases:
+	//      [* * * * *]              actual data
+	//  [o o]                        1. attempted indexing: lo, hi both out of bounds
+	//  [o o o o o o ]               2. attempted indexing: hi in bounds, lo out
+	//  [o o o o o o o o o o o o]    3. attempted indexing: lo, hi both out of bounds
+	//        [o o o]                4. attempted indexing: lo, hi in bounds
+	//        [o o o o o o ]         5. attempted indexing: lo in bounds, hi out
+	//                  [o o o o]    6. attempted indexing: lo, hi both out of bounds
+
+	if lowerZindex < 0 {
+		lowerZindex = 0
+		if lowerZindex > upperZindex {
+			return true, nil, 0, 0
+		}
+	}
+	if upperZindex > n-1 {
+		upperZindex = n - 1
+		if lowerZindex > upperZindex {
+			return true, nil, 0, 0
+		}
+	}
+
+	return false, nil, lowerZindex, upperZindex
+}
